import { __decorate, __metadata, __param } from "tslib";
import { injectable, multiInject } from 'inversify';
import { DEPENDENCIES } from '../../../container/container.const';
import { pipeMappers } from '../../pipe-mappers';
/**
 * Simple Empathy facet mapper.
 *
 * @public
 */
var EmpathySimpleFacetMapper = /** @class */ (function () {
    function EmpathySimpleFacetMapper(filterMappers) {
        this.mapFilter = pipeMappers.apply(void 0, filterMappers);
    }
    EmpathySimpleFacetMapper.prototype.map = function (rawFacet, facet, context) {
        if (facet.modelName === 'SimpleFacet') {
            Object.assign(facet, {
                filters: this.mapFilters(facet, rawFacet.values, context)
            });
        }
        return facet;
    };
    EmpathySimpleFacetMapper.prototype.mapFilters = function (facet, rawFilters, context) {
        var _this = this;
        if (rawFilters === void 0) { rawFilters = []; }
        return rawFilters.map(function (rawFilter) { return _this.mapFilter(rawFilter, { facetId: facet.id }, context); });
    };
    EmpathySimpleFacetMapper = __decorate([
        injectable(),
        __param(0, multiInject(DEPENDENCIES.ResponseMappers.simpleFilter)),
        __metadata("design:paramtypes", [Array])
    ], EmpathySimpleFacetMapper);
    return EmpathySimpleFacetMapper;
}());
export { EmpathySimpleFacetMapper };
//# sourceMappingURL=empathy-simple-facet.mapper.js.map