import { ClicksRecommendationsRequest, ClicksRecommendationsResponse, DeepPartial, FeatureNames, NextQueriesRequest, NextQueriesResponse, QueriesRecommendationsRequest, QueriesRecommendationsResponse, RelatedTagsRequest, RelatedTagsResponse, RequestOptions, SearchAdapter, SearchByIdRequest, SearchByIdResponse, SearchRequest, SearchResponse, SectionRecommendationsRequest, SectionRecommendationsResponse, SuggestionsRequest, SuggestionsResponse, TopRecommendationsRequest, TopRecommendationsResponse, TrackingRequest, UserRecommendationsRequest, UserRecommendationsResponse } from '../types';
import { EmpathyAdapterConfig } from './config/empathy-adapter-config.types';
import { EmpathyAdapterConfigChangedListener, Requestor } from './empathy-adapter.types';
import { CacheService } from './services/cache-service.types';
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare class EmpathyAdapter implements SearchAdapter<EmpathyAdapterConfig> {
    protected readonly config: EmpathyAdapterConfig;
    protected readonly requestors: Record<FeatureNames, Requestor>;
    protected readonly cache: CacheService;
    protected configChangedListeners: Set<EmpathyAdapterConfigChangedListener>;
    constructor(config: EmpathyAdapterConfig, requestors: Record<FeatureNames, Requestor>, cache: CacheService);
    getNextQueries(request: NextQueriesRequest, requestOptions?: RequestOptions): Promise<NextQueriesResponse>;
    getTopRecommendations(request: TopRecommendationsRequest, requestOptions?: RequestOptions): Promise<TopRecommendationsResponse>;
    getClicksRecommendations(request: ClicksRecommendationsRequest, requestOptions?: RequestOptions): Promise<ClicksRecommendationsResponse>;
    getQueriesRecommendations(request: QueriesRecommendationsRequest, requestOptions?: RequestOptions): Promise<QueriesRecommendationsResponse>;
    getSectionRecommendations(request: SectionRecommendationsRequest, requestOptions?: RequestOptions): Promise<SectionRecommendationsResponse>;
    getUserRecommendations(request: UserRecommendationsRequest, requestOptions?: RequestOptions): Promise<UserRecommendationsResponse>;
    getRelatedTags(request: RelatedTagsRequest, requestOptions?: RequestOptions): Promise<RelatedTagsResponse>;
    getSuggestions(request: SuggestionsRequest, requestOptions?: RequestOptions): Promise<SuggestionsResponse>;
    search(request: SearchRequest, requestOptions?: RequestOptions): Promise<SearchResponse>;
    searchById(request: SearchByIdRequest, requestOptions?: RequestOptions): Promise<SearchByIdResponse>;
    track(trackingRequest: TrackingRequest): Promise<void>;
    invalidateCache(): void;
    setConfig(newConfig: DeepPartial<EmpathyAdapterConfig>): void;
    addConfigChangedListener(listener: EmpathyAdapterConfigChangedListener): void;
    removeConfigChangedListener(listener: EmpathyAdapterConfigChangedListener): void;
    protected notifyConfigChangedListeners(): void;
}
