import { Dictionary, FeatureNames, RequestOptions } from '../../types';
import { EmpathyAdapterConfig, FeatureConfig } from '../config/empathy-adapter-config.types';
import { BeforeRequest, BeforeRequestContext, BeforeResponseTransform, BeforeResponseTransformContext, MapFn, MapRequest, Requestor, ResponseMapper, ResponseMapperContext, ResponseTransformed, ResponseTransformedContext } from '../empathy-adapter.types';
import { EntityNames } from '../entities.types';
import { HttpClient } from '../http-clients/http-client.types';
import { EndpointsService } from '../services/endpoints-service.types';
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare class FeatureRequestor<RequestType, ResponseType extends Dictionary<any>> implements Requestor<RequestType, ResponseType> {
    protected readonly config: EmpathyAdapterConfig;
    protected readonly feature: FeatureNames;
    protected readonly httpClient: HttpClient;
    protected readonly endpointsService: EndpointsService;
    protected readonly beforeRequest: BeforeRequest[];
    protected readonly beforeResponseTransformed: BeforeResponseTransform[];
    protected readonly responseTransformed: ResponseTransformed[];
    protected mapRequest: MapRequest;
    protected responseMappers: Record<EntityNames, MapFn>;
    protected featureConfig: FeatureConfig<any>;
    constructor(config: EmpathyAdapterConfig, feature: FeatureNames, httpClient: HttpClient, endpointsService: EndpointsService, requestMappers: ResponseMapper[], mappers: Record<EntityNames, ResponseMapper[]>, beforeRequest?: BeforeRequest[], beforeResponseTransformed?: BeforeResponseTransform[], responseTransformed?: ResponseTransformed[]);
    request(rawRequest: RequestType, requestOptions?: RequestOptions): Promise<ResponseType>;
    protected runHooks(hooks: Function[], context: BeforeRequestContext | BeforeResponseTransformContext | ResponseTransformedContext): void;
    protected transformResponse(rawResponse: any, context: ResponseMapperContext): ResponseType;
    protected transformResponseSelection(rawResponseSelection: any, entityName: EntityNames, context: ResponseMapperContext): any;
}
